@@ -14,7 +14,7 @@ $parser->YYData->{verbose_error} = 1;		# 0, 1
 $parser->YYData->{verbose_warning} = 1;		# 0, 1
 $parser->YYData->{verbose_info} = 1;		# 0, 1
 $parser->YYData->{verbose_deprecated} = 0;	# 0, 1 (concerns only version '2.4' and upper)
-$parser->YYData->{symbtab} = new Symbtab($parser);
+$parser->YYData->{symbtab} = new CORBA::IDL::Symbtab($parser);
 my $cflags = '-D__idl2wsdl';
 if ($Parser::IDL_version lt '3.0') {
 	$cflags .= ' -D_PRE_3_0_COMPILER_';
@@ -25,7 +25,19 @@ if ($^O eq 'MSWin32') {
 } else {
 	$parser->YYData->{preprocessor} = 'cpp -C ' . $cflags;
 }
-$parser->getopts("b:i:s:x");
+$parser->getopts("b:hi:s:vx");
+if ($parser->YYData->{opt_v}) {
+	print "CORBA::XMLSchemas $CORBA::XMLSchemas::VERSION\n";
+	print "CORBA::IDL $CORBA::IDL::VERSION\n";
+	print "IDL $Parser::IDL_version\n";
+	print "$0\n";
+	print "Perl $]\n";
+	exit;
+}
+if ($parser->YYData->{opt_h}) {
+	use Pod::Usage;
+	pod2usage(-verbose => 1);
+}
 $parser->Run(@ARGV);
 $parser->YYData->{symbtab}->CheckForward();
 $parser->YYData->{symbtab}->CheckRepositoryID();
@@ -56,14 +68,14 @@ if (        exists $parser->YYData->{root}
 			and $parser->YYData->{opt_x} ) {
 		$parser->YYData->{symbtab}->Export();
 	}
-	$parser->YYData->{root}->visitName(new XsdNameVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::XMLSchemas::nameVisitor($parser));
 	if (exists $parser->YYData->{opt_s} and $parser->YYData->{opt_s} eq "rng") {
-		$parser->YYData->{root}->visit(new RelaxngVisitor($parser));
+		$parser->YYData->{root}->visit(new CORBA::XMLSchemas::relaxngVisitor($parser));
 	} else {
-		$parser->YYData->{root}->visit(new XsdVisitor($parser));
+		$parser->YYData->{root}->visit(new CORBA::XMLSchemas::xsdVisitor($parser));
 	}
-	$parser->YYData->{root}->visit(new WsdlVisitor($parser, $parser->YYData->{opt_s}));
-	$parser->YYData->{root}->visit(new WsdlSoapBindingVisitor($parser));
+	$parser->YYData->{root}->visit(new CORBA::XMLSchemas::wsdlVisitor($parser, $parser->YYData->{opt_s}));
+	$parser->YYData->{root}->visit(new CORBA::XMLSchemas::wsdlSoapBindingVisitor($parser));
 }
 
 __END__
@@ -78,7 +90,7 @@ idl2soap [options] I<spec>.idl
 
 =head1 OPTIONS
 
-All options are forwarded to C preprocessor, except -b -i -s -x.
+All options are forwarded to C preprocessor, except -b -h -i -s -v -x.
 
 With the GNU C Compatible Compiler Processor, useful options are :
 
@@ -104,6 +116,10 @@ Specific options :
 
 Specify a base uri for location of import.
 
+=item B<-h>
+
+Display help.
+
 =item B<-i> I<directory>
 
 Specify a path for import (only for IDL version 3.0).
@@ -112,6 +128,10 @@ Specify a path for import (only for IDL version 3.0).
 
 Specify the schema used. By default I<xsd>.
 
+=item B<-v>
+
+Display version.
+
 =item B<-x>
 
 Enable export (only for IDL version 3.0).
@@ -156,7 +176,7 @@ cpp, perl, idl2html, idl2java, idl2xsd, idl2rng, idl2wsdl
 
 =head1 COPYRIGHT
 
-(c) 2003 Francois PERRAD, France. All rights reserved.
+(c) 2003-2004 Francois PERRAD, France. All rights reserved.
 
 This program and all CORBA::XMLSchemas modules are distributed
 under the terms of the Artistic Licence.
